summaryrefslogtreecommitdiff
path: root/TAO/tao/IIOP_Transport.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'TAO/tao/IIOP_Transport.cpp')
-rw-r--r--TAO/tao/IIOP_Transport.cpp9
1 files changed, 5 insertions, 4 deletions
diff --git a/TAO/tao/IIOP_Transport.cpp b/TAO/tao/IIOP_Transport.cpp
index fa7a726abb0..a8e610e14f7 100644
--- a/TAO/tao/IIOP_Transport.cpp
+++ b/TAO/tao/IIOP_Transport.cpp
@@ -117,7 +117,7 @@ TAO_IIOP_Transport::_nil (void)
void
TAO_IIOP_Transport::resume_connection (ACE_Reactor *reactor)
{
- this->handler_->resume_handler (reactor);
+ (void) reactor->resume_handler (this->handler_);
}
void
@@ -161,7 +161,8 @@ TAO_IIOP_Transport::send (const ACE_Message_Block *mblk, ACE_Time_Value *s)
// @@ Fred, this should NOT be a local constant... It should use a
// macro defined in OS.h...
- iovec iov[IOV_MAX];
+ const int TAO_WRITEV_MAX = 16;
+ iovec iov[TAO_WRITEV_MAX];
int iovcnt = 0;
ssize_t n = 0;
ssize_t nbytes = 0;
@@ -182,8 +183,8 @@ TAO_IIOP_Transport::send (const ACE_Message_Block *mblk, ACE_Time_Value *s)
// platforms do not implement writev() there we should copy
// the data into a buffer and call send_n(). In other cases
// there may be some limits on the size of the iovec, there
- // we should set IOV_MAX to that limit.
- if (iovcnt == IOV_MAX)
+ // we should set TAO_WRITEV_MAX to that limit.
+ if (iovcnt == TAO_WRITEV_MAX)
{
n = this->handler_->peer ().sendv_n ((const iovec *) iov,
iovcnt);